==> vertx-kafka-client-3.4.0-sources.jar: io/vertx/groovy/kafka/client/producer/KafkaProducer_GroovyExtension.java <==
package io.vertx.groovy.kafka.client.producer;
public class KafkaProducer_GroovyExtension {
  public static io.vertx.kafka.client.producer.KafkaProducer<java.lang.Object,java.lang.Object> write(io.vertx.kafka.client.producer.KafkaProducer<Object, Object> j_receiver, io.vertx.kafka.client.producer.KafkaProducerRecord<java.lang.Object,java.lang.Object> record, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.Map<String, Object>>> handler) {
    io.vertx.groovy.kafka.client.internal.ConversionHelper.wrap(j_receiver.write(record,
      handler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.kafka.client.producer.RecordMetadata>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.kafka.client.producer.RecordMetadata> ar) {
        handler.handle(ar.map(event -> io.vertx.groovy.kafka.client.internal.ConversionHelper.applyIfNotNull(event, a -> io.vertx.groovy.kafka.client.internal.ConversionHelper.fromJsonObject(a.toJson()))));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.kafka.client.producer.KafkaProducer<java.lang.Object,java.lang.Object> partitionsFor(io.vertx.kafka.client.producer.KafkaProducer<Object, Object> j_receiver, java.lang.String topic, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.List<java.util.Map<String, Object>>>> handler) {
    io.vertx.groovy.kafka.client.internal.ConversionHelper.wrap(j_receiver.partitionsFor(topic,
      handler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.List<io.vertx.kafka.client.common.PartitionInfo>>>() {
      public void handle(io.vertx.core.AsyncResult<java.util.List<io.vertx.kafka.client.common.PartitionInfo>> ar) {
        handler.handle(ar.map(event -> io.vertx.groovy.kafka.client.internal.ConversionHelper.applyIfNotNull(event, list -> list.stream().map(elt -> io.vertx.groovy.kafka.client.internal.ConversionHelper.applyIfNotNull(elt, a -> io.vertx.groovy.kafka.client.internal.ConversionHelper.fromJsonObject(a.toJson()))).collect(java.util.stream.Collectors.toList()))));
      }
    } : null));
    return j_receiver;
  }
}

==> vertx-kafka-client-3.5.2-sources.jar: io/vertx/groovy/kafka/client/producer/KafkaProducer_GroovyExtension.java <==
package io.vertx.groovy.kafka.client.producer;
public class KafkaProducer_GroovyExtension {
  public static io.vertx.kafka.client.producer.KafkaProducer<java.lang.Object,java.lang.Object> write(io.vertx.kafka.client.producer.KafkaProducer<Object, Object> j_receiver, io.vertx.kafka.client.producer.KafkaProducerRecord<java.lang.Object,java.lang.Object> record, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.Map<String, Object>>> handler) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.write(record,
      handler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.kafka.client.producer.RecordMetadata>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.kafka.client.producer.RecordMetadata> ar) {
        handler.handle(ar.map(event -> event != null ? io.vertx.core.impl.ConversionHelper.fromJsonObject(event.toJson()) : null));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.kafka.client.producer.KafkaProducer<java.lang.Object,java.lang.Object> partitionsFor(io.vertx.kafka.client.producer.KafkaProducer<Object, Object> j_receiver, java.lang.String topic, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.List<java.util.Map<String, Object>>>> handler) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.partitionsFor(topic,
      handler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.List<io.vertx.kafka.client.common.PartitionInfo>>>() {
      public void handle(io.vertx.core.AsyncResult<java.util.List<io.vertx.kafka.client.common.PartitionInfo>> ar) {
        handler.handle(ar.map(event -> event != null ? event.stream().map(elt -> elt != null ? io.vertx.core.impl.ConversionHelper.fromJsonObject(elt.toJson()) : null).collect(java.util.stream.Collectors.toList()) : null));
      }
    } : null));
    return j_receiver;
  }
}
